private static class WebFormScript
{
	public static string GridColumn(IItem item)
	{
		if (item is AttributeElement)
			return GridAttribute((AttributeElement)item);

		if (item is VariableElement)
			return GridVariable((VariableElement)item);

		throw new PatternApplicationException("Unexpected attributes item: not an attribute or variable");
	}

	public static string GridAttribute(AttributeElement att)
	{
		string defaultThemeClass = K2BEntityServicesSettings.Current.Theme.ReadonlyGridAttribute;
		if (att.Attribute.Type == eDBType.BINARY)
			defaultThemeClass = K2BEntityServicesSettings.Current.Theme.ReadonlyGridBlobAttribute;

		string themeClass = GetThemeClass(att, defaultThemeClass);
		Dictionary<string, object> properties = new Dictionary<string, object>();
		GetControlInfo(att, properties);

		return WebForm.GridAttribute(att.AttributeName, themeClass, att.Description, att.Visible, null, properties);
	}

	public static string GridVariable(VariableElement var)
	{
		string themeClass = GetThemeClass(var, K2BEntityServicesSettings.Current.Theme.ReadonlyGridAttribute);
		Dictionary<string, object> properties = new Dictionary<string, object>();
		GetControlInfo(var, properties);

		return WebForm.GridVariable(var.VariableName, themeClass, var.Description, var.Visible, null, properties);
	}

	public static string Item(IItem item)
	{
		if (item is AttributeElement)
			return Attribute((AttributeElement)item);

		if (item is VariableElement)
			return Variable((VariableElement)item);

		throw new PatternApplicationException("Unexpected attributes item: not an attribute or variable");
	}

	public static string Attribute(AttributeElement att)
	{
		string defaultThemeClass = K2BEntityServicesSettings.Current.Theme.ReadonlyAttribute;
		if (att.Attribute.Type == eDBType.BINARY)
			defaultThemeClass = K2BEntityServicesSettings.Current.Theme.ReadonlyBlobAttribute;

		string themeClass = GetThemeClass(att, defaultThemeClass);
		Dictionary<string, object> properties = new Dictionary<string, object>();
		GetControlInfo(att, properties);

		return WebForm.Attribute(att.AttributeName, themeClass, null, properties);
	}

	public static string HiddenAttribute(string attName)
	{
		Dictionary<string, object> properties = new Dictionary<string, object>();
		properties[Properties.ATT.ControlType] = Properties.ATT.ControlType_Values.Edit;
		properties[Properties.ATT.InputType] = Properties.ATT.InputType_Values.Values;
		return WebForm.Attribute(attName, null, null, properties);
	}

	public static string Variable(VariableElement var)
	{
		string themeClass = GetThemeClass(var, K2BEntityServicesSettings.Current.Theme.ReadonlyAttribute);
		Dictionary<string, object> properties = new Dictionary<string, object>();
		GetControlInfo(var, properties);

		return WebForm.Variable(var.VariableName, themeClass, null, properties);
	}

	private static void GetControlInfo(IItem item, Dictionary<string, object> properties)
	{
		ITypedObject typeInfo = item.TypeInfo;
		if (typeInfo != null && typeInfo is Artech.Common.Properties.PropertiesObject)
		{
			Artech.Common.Properties.PropertiesObject props = (Artech.Common.Properties.PropertiesObject)typeInfo;
			int controlType = props.GetPropertyValue<int>(Properties.ATT.ControlType);
			int editSuggest = props.GetPropertyValue<int>(Properties.ATT.Suggest);
			int editInputType = props.GetPropertyValue<int>(Properties.ATT.InputType);

			if ((controlType == Properties.ATT.ControlType_Values.DynamicComboBox) ||
				(controlType == Properties.ATT.ControlType_Values.DynamicListBox) ||
				(controlType == Properties.ATT.ControlType_Values.Edit && (editInputType == Properties.ATT.InputType_Values.Descriptions || editSuggest != Properties.ATT.Suggest_Values.No)))
			{
				properties[Properties.ATT.ControlType] = Properties.ATT.ControlType_Values.Edit;
				properties[Properties.ATT.InputType] = Properties.ATT.InputType_Values.Values;
			}
		}
	}

	private static string GetThemeClass(IItem item, string defaultClass)
	{
		if (!String.IsNullOrEmpty(item.ThemeClass))
			return item.ThemeClass;

		if (!String.IsNullOrEmpty(defaultClass))
			return defaultClass;

		return null;
	}
}
